# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .subscription_test_params import SubscriptionTestParams as SubscriptionTestParams
from .subscription_create_params import SubscriptionCreateParams as SubscriptionCreateParams
from .subscription_update_params import SubscriptionUpdateParams as SubscriptionUpdateParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .translate import (
    TranslateResource,
    AsyncTranslateResource,
    TranslateResourceWithRawResponse,
    AsyncTranslateResourceWithRawResponse,
    TranslateResourceWithStreamingResponse,
    AsyncTranslateResourceWithStreamingResponse,
)

__all__ = [
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
    "TranslateResource",
    "AsyncTranslateResource",
    "TranslateResourceWithRawResponse",
    "AsyncTranslateResourceWithRawResponse",
    "TranslateResourceWithStreamingResponse",
    "AsyncTranslateResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .memory import (
    MemoryResource,
    AsyncMemoryResource,
    MemoryResourceWithRawResponse,
    AsyncMemoryResourceWithRawResponse,
    MemoryResourceWithStreamingResponse,
    AsyncMemoryResourceWithStreamingResponse,
)

__all__ = [
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
    "MemoryResource",
    "AsyncMemoryResource",
    "MemoryResourceWithRawResponse",
    "AsyncMemoryResourceWithRawResponse",
    "MemoryResourceWithStreamingResponse",
    "AsyncMemoryResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .format import (
    FormatResource,
    AsyncFormatResource,
    FormatResourceWithRawResponse,
    AsyncFormatResourceWithRawResponse,
    FormatResourceWithStreamingResponse,
    AsyncFormatResourceWithStreamingResponse,
)

__all__ = [
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
    "FormatResource",
    "AsyncFormatResource",
    "FormatResourceWithRawResponse",
    "AsyncFormatResourceWithRawResponse",
    "FormatResourceWithStreamingResponse",
    "AsyncFormatResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev
from tests.utils import assert_matches_type
from casedev.types.vault import GraphragInitResponse, GraphragGetStatsResponse, GraphragProcessObjectResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestGraphrag:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_get_stats(self, client: Casedev) -> None:
        graphrag = client.vault.graphrag.get_stats(
            "id",
        )
        assert_matches_type(GraphragGetStatsResponse, graphrag, path=["response"])

    @parametrize
    def test_raw_response_get_stats(self, client: Casedev) -> None:
        response = client.vault.graphrag.with_raw_response.get_stats(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graphrag = response.parse()
        assert_matches_type(GraphragGetStatsResponse, graphrag, path=["response"])

    @parametrize
    def test_streaming_response_get_stats(self, client: Casedev) -> None:
        with client.vault.graphrag.with_streaming_response.get_stats(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graphrag = response.parse()
            assert_matches_type(GraphragGetStatsResponse, graphrag, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_get_stats(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.graphrag.with_raw_response.get_stats(
                "",
            )

    @parametrize
    def test_method_init(self, client: Casedev) -> None:
        graphrag = client.vault.graphrag.init(
            "id",
        )
        assert_matches_type(GraphragInitResponse, graphrag, path=["response"])

    @parametrize
    def test_raw_response_init(self, client: Casedev) -> None:
        response = client.vault.graphrag.with_raw_response.init(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graphrag = response.parse()
        assert_matches_type(GraphragInitResponse, graphrag, path=["response"])

    @parametrize
    def test_streaming_response_init(self, client: Casedev) -> None:
        with client.vault.graphrag.with_streaming_response.init(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graphrag = response.parse()
            assert_matches_type(GraphragInitResponse, graphrag, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_init(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.graphrag.with_raw_response.init(
                "",
            )

    @parametrize
    def test_method_process_object(self, client: Casedev) -> None:
        graphrag = client.vault.graphrag.process_object(
            object_id="objectId",
            id="id",
        )
        assert_matches_type(GraphragProcessObjectResponse, graphrag, path=["response"])

    @parametrize
    def test_raw_response_process_object(self, client: Casedev) -> None:
        response = client.vault.graphrag.with_raw_response.process_object(
            object_id="objectId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graphrag = response.parse()
        assert_matches_type(GraphragProcessObjectResponse, graphrag, path=["response"])

    @parametrize
    def test_streaming_response_process_object(self, client: Casedev) -> None:
        with client.vault.graphrag.with_streaming_response.process_object(
            object_id="objectId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graphrag = response.parse()
            assert_matches_type(GraphragProcessObjectResponse, graphrag, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_process_object(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.graphrag.with_raw_response.process_object(
                object_id="objectId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            client.vault.graphrag.with_raw_response.process_object(
                object_id="",
                id="id",
            )


class TestAsyncGraphrag:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_get_stats(self, async_client: AsyncCasedev) -> None:
        graphrag = await async_client.vault.graphrag.get_stats(
            "id",
        )
        assert_matches_type(GraphragGetStatsResponse, graphrag, path=["response"])

    @parametrize
    async def test_raw_response_get_stats(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.graphrag.with_raw_response.get_stats(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graphrag = await response.parse()
        assert_matches_type(GraphragGetStatsResponse, graphrag, path=["response"])

    @parametrize
    async def test_streaming_response_get_stats(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.graphrag.with_streaming_response.get_stats(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graphrag = await response.parse()
            assert_matches_type(GraphragGetStatsResponse, graphrag, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_get_stats(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.graphrag.with_raw_response.get_stats(
                "",
            )

    @parametrize
    async def test_method_init(self, async_client: AsyncCasedev) -> None:
        graphrag = await async_client.vault.graphrag.init(
            "id",
        )
        assert_matches_type(GraphragInitResponse, graphrag, path=["response"])

    @parametrize
    async def test_raw_response_init(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.graphrag.with_raw_response.init(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graphrag = await response.parse()
        assert_matches_type(GraphragInitResponse, graphrag, path=["response"])

    @parametrize
    async def test_streaming_response_init(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.graphrag.with_streaming_response.init(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graphrag = await response.parse()
            assert_matches_type(GraphragInitResponse, graphrag, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_init(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.graphrag.with_raw_response.init(
                "",
            )

    @parametrize
    async def test_method_process_object(self, async_client: AsyncCasedev) -> None:
        graphrag = await async_client.vault.graphrag.process_object(
            object_id="objectId",
            id="id",
        )
        assert_matches_type(GraphragProcessObjectResponse, graphrag, path=["response"])

    @parametrize
    async def test_raw_response_process_object(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.graphrag.with_raw_response.process_object(
            object_id="objectId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graphrag = await response.parse()
        assert_matches_type(GraphragProcessObjectResponse, graphrag, path=["response"])

    @parametrize
    async def test_streaming_response_process_object(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.graphrag.with_streaming_response.process_object(
            object_id="objectId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graphrag = await response.parse()
            assert_matches_type(GraphragProcessObjectResponse, graphrag, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_process_object(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.graphrag.with_raw_response.process_object(
                object_id="objectId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `object_id` but received ''"):
            await async_client.vault.graphrag.with_raw_response.process_object(
                object_id="",
                id="id",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["SuperdocResource", "AsyncSuperdocResource"]


class SuperdocResource(SyncAPIResource):
    @cached_property
    def v1(self) -> V1Resource:
        return V1Resource(self._client)

    @cached_property
    def with_raw_response(self) -> SuperdocResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return SuperdocResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SuperdocResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return SuperdocResourceWithStreamingResponse(self)


class AsyncSuperdocResource(AsyncAPIResource):
    @cached_property
    def v1(self) -> AsyncV1Resource:
        return AsyncV1Resource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncSuperdocResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSuperdocResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSuperdocResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncSuperdocResourceWithStreamingResponse(self)


class SuperdocResourceWithRawResponse:
    def __init__(self, superdoc: SuperdocResource) -> None:
        self._superdoc = superdoc

    @cached_property
    def v1(self) -> V1ResourceWithRawResponse:
        return V1ResourceWithRawResponse(self._superdoc.v1)


class AsyncSuperdocResourceWithRawResponse:
    def __init__(self, superdoc: AsyncSuperdocResource) -> None:
        self._superdoc = superdoc

    @cached_property
    def v1(self) -> AsyncV1ResourceWithRawResponse:
        return AsyncV1ResourceWithRawResponse(self._superdoc.v1)


class SuperdocResourceWithStreamingResponse:
    def __init__(self, superdoc: SuperdocResource) -> None:
        self._superdoc = superdoc

    @cached_property
    def v1(self) -> V1ResourceWithStreamingResponse:
        return V1ResourceWithStreamingResponse(self._superdoc.v1)


class AsyncSuperdocResourceWithStreamingResponse:
    def __init__(self, superdoc: AsyncSuperdocResource) -> None:
        self._superdoc = superdoc

    @cached_property
    def v1(self) -> AsyncV1ResourceWithStreamingResponse:
        return AsyncV1ResourceWithStreamingResponse(self._superdoc.v1)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .compute import (
    ComputeResource,
    AsyncComputeResource,
    ComputeResourceWithRawResponse,
    AsyncComputeResourceWithRawResponse,
    ComputeResourceWithStreamingResponse,
    AsyncComputeResourceWithStreamingResponse,
)

__all__ = [
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
    "ComputeResource",
    "AsyncComputeResource",
    "ComputeResourceWithRawResponse",
    "AsyncComputeResourceWithRawResponse",
    "ComputeResourceWithStreamingResponse",
    "AsyncComputeResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev
from tests.utils import assert_matches_type
from casedev.types.privilege import V1DetectResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV1:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_detect(self, client: Casedev) -> None:
        v1 = client.privilege.v1.detect()
        assert_matches_type(V1DetectResponse, v1, path=["response"])

    @parametrize
    def test_method_detect_with_all_params(self, client: Casedev) -> None:
        v1 = client.privilege.v1.detect(
            categories=["attorney_client"],
            content="content",
            document_id="document_id",
            include_rationale=True,
            jurisdiction="US-Federal",
            model="model",
            vault_id="vault_id",
        )
        assert_matches_type(V1DetectResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_detect(self, client: Casedev) -> None:
        response = client.privilege.v1.with_raw_response.detect()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1DetectResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_detect(self, client: Casedev) -> None:
        with client.privilege.v1.with_streaming_response.detect() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1DetectResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncV1:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_detect(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.privilege.v1.detect()
        assert_matches_type(V1DetectResponse, v1, path=["response"])

    @parametrize
    async def test_method_detect_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.privilege.v1.detect(
            categories=["attorney_client"],
            content="content",
            document_id="document_id",
            include_rationale=True,
            jurisdiction="US-Federal",
            model="model",
            vault_id="vault_id",
        )
        assert_matches_type(V1DetectResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_detect(self, async_client: AsyncCasedev) -> None:
        response = await async_client.privilege.v1.with_raw_response.detect()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1DetectResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_detect(self, async_client: AsyncCasedev) -> None:
        async with async_client.privilege.v1.with_streaming_response.detect() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1DetectResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["RunCreateParams"]


class RunCreateParams(TypedDict, total=False):
    agent_id: Required[Annotated[str, PropertyInfo(alias="agentId")]]
    """ID of the agent to run"""

    prompt: Required[str]
    """Task prompt for the agent"""

    guidance: Optional[str]
    """Additional guidance for this run"""

    model: Optional[str]
    """Override the agent default model for this run"""
